@@ -462,7 +462,7 @@ class zetldbaccess:
 		if etl_name != '':
 			zsql += "WHERE upper(etl_name) like upper('" + etl_name + "') "
 		zsql += ' ORDER BY etl_name '
-		etl_list = self.db.query()
+		etl_list = self.db.query(zsql)
 		for etl in etl_list:
 			etl_name = etl[0]
 			qry = "SELECT stepnum,cmdfile,steptablename,estrowcount FROM " + self.db.db_conn_dets.DB_SCHEMA + ".z_etl WHERE etl_name = '" + etl_name + "' ORDER BY stepnum"
