@@ -3,7 +3,7 @@
 
 DB_TYPE		= MySQL
 DB_USERNAME	= dad
-DB_USERPWD  = 4165605869
+DB_USERPWD  = **********
 DB_HOST		= localhost
 DB_PORT		= 3306
 DB_NAME		= nfldb
